@@ -7,12 +7,12 @@ use English qw(-no_match_vars);
 
 use base 'FLV::Base';
 
-use FLV::Constants;
+use FLV::Util;
 use FLV::AudioTag;
 use FLV::VideoTag;
 use FLV::MetaTag;
 
-our $VERSION = '0.16';
+our $VERSION = '0.17';
 
 =for stopwords subtag
 
@@ -35,6 +35,8 @@ This is a subclass of FLV::Base.
 
 =item $self->parse($fileinst)
 
+=item $self->parse($fileinst, {opt => $optvalue, ...})
+
 Takes a FLV::File instance and extracts an FLV tag from the file
 stream.  This method then multiplexes that tag into one of the
 subtypes: video, audio or meta.  This method throws exceptions if the
@@ -45,23 +47,31 @@ retrieved with get_payload().
 
 There is no return value.
 
+An option of C<record_positions => 1> causes the byte offset of the
+tag to be stored in the instance.  This is intended for testing and/or
+debugging, so there is no public accessor for that property.
+
 =cut
 
 sub parse
 {
    my $self = shift;
    my $file = shift;
+   my $opts = shift;
+   $opts ||= {};
 
    my $content = $file->get_bytes(11);
-   
-   my ($type, @datasize, @timestamp, $reserved);
-   ($type, $datasize[0], $datasize[1], $datasize[2],
-    $timestamp[1], $timestamp[2], $timestamp[3], $timestamp[0])
-       = unpack 'CCCCCCCC', $content;
 
-   my $datasize  = ($datasize[0]  * 256 + $datasize[1])  * 256 + $datasize[2];
+   my ($type, @datasize, @timestamp, $reserved);
+   (
+      $type,         $datasize[0],  $datasize[1],  $datasize[2],
+      $timestamp[1], $timestamp[2], $timestamp[3], $timestamp[0]
+   ) = unpack 'CCCCCCCC', $content;
+
+   my $datasize = ($datasize[0] * 256 + $datasize[1]) * 256 + $datasize[2];
    my $timestamp
-       = (($timestamp[0] * 256 + $timestamp[1]) * 256 + $timestamp[2]) * 256 + $timestamp[3];
+       = (($timestamp[0] * 256 + $timestamp[1]) * 256 + $timestamp[2]) * 256 +
+       $timestamp[3];
 
    if ($timestamp > 4_000_000_000 || $timestamp < 0)
    {
@@ -70,15 +80,25 @@ sub parse
 
    if ($datasize < 11)
    {
-      die 'Tag size is too small ('.$datasize.') at byte ' . $file->get_pos(-10);
+      die "Tag size is too small ($datasize) at byte " . $file->get_pos(-10);
    }
 
-   my $payload_class = $TAG_CLASSES{$type} 
-      or die 'Unknown tag type ' . $type . ' at byte ' . $file->get_pos(-11);
+   my $payload_class = $TAG_CLASSES{$type};
+   if (!$payload_class)
+   {
+      die "Unknown tag type $type at byte " . $file->get_pos(-11);
+   }
 
    $self->{payload} = $payload_class->new();
-   $self->{payload}->{start} = $timestamp; # millisec
-   $self->{payload}->parse($file, $datasize); # might throw exception
+   $self->{payload}->{start} = $timestamp;    # millisec
+   if ($opts->{record_positions})
+   {
+
+      # for testing/debugging only!
+      $self->{payload}->{_pos} = $file->get_pos(-11);
+      $self->{payload}->{_pos} =~ s/\D.*\z//xms;
+   }
+   $self->{payload}->parse($file, $datasize);    # might throw exception
 
    return;
 }
@@ -113,8 +133,12 @@ sub serialize
    my $tag         = shift || croak 'Please specify a tag';
    my $filehandle  = shift || croak 'Please specify a filehandle';
 
-   my $tag_type = {reverse %TAG_CLASSES}->{ref $tag} || die 'Unknown tag class ' . ref $tag;
-   
+   my $tag_type = { reverse %TAG_CLASSES }->{ ref $tag };
+   if (!$tag_type)
+   {
+      die 'Unknown tag class ' . ref $tag;
+   }
+
    my @timestamp = (
       $tag->{start} >> 24 & 0xff,
       $tag->{start} >> 16 & 0xff,
@@ -123,13 +147,11 @@ sub serialize
    );
    my $data     = $tag->serialize();
    my $datasize = length $data;
-   my @datasize = (
-      $datasize >> 16 & 0xff,
-      $datasize >> 8 & 0xff,
-      $datasize & 0xff,
-   );
+   my @datasize
+       = ($datasize >> 16 & 0xff, $datasize >> 8 & 0xff, $datasize & 0xff);
 
-   my $header = pack 'CCCCCCCCCCC', $tag_type, @datasize, @timestamp[1..3], $timestamp[0], 0, 0, 0;
+   my $header = pack 'CCCCCCCCCCC', $tag_type, @datasize, @timestamp[1 .. 3],
+       $timestamp[0], 0, 0, 0;
    return if (!print {$filehandle} $header);
    return if (!print {$filehandle} $data);
    return 11 + $datasize;
