@@ -7,9 +7,9 @@ use English qw(-no_match_vars);
 
 use base 'FLV::Base';
 
-use FLV::Constants;
+use FLV::Util;
 
-our $VERSION = '0.16';
+our $VERSION = '0.17';
 
 =for stopwords codec
 
@@ -52,7 +52,7 @@ sub parse
 
    # The spec PDF is wrong -- type comes first, then codec
    my $type  = ($flags >> 4) & 0x0f;
-   my $codec =  $flags       & 0x0f;
+   my $codec = $flags & 0x0f;
 
    if (!exists $VIDEO_CODEC_IDS{$codec})
    {
@@ -70,13 +70,13 @@ sub parse
 
    $self->{data} = $file->get_bytes($datasize - 1);
 
-   my $result
-       = $self->{codec} == 2 ? $self->_parse_h263($pos)
+   my $result =
+         $self->{codec} == 2 ? $self->_parse_h263($pos)
        : $self->{codec} == 3 ? $self->_parse_screen_video($pos)
        : $self->{codec} == 4 ? $self->_parse_on2vp6($pos)
        : $self->{codec} == 5 ? $self->_parse_on2vp6_alpha($pos)
        : $self->{codec} == 6 ? $self->_parse_screen_video($pos)
-       : die 'Unknown video type';
+       :                       die 'Unknown video type';
 
    return;
 }
@@ -95,28 +95,30 @@ sub _parse_h263
       (ord pack 'B8', substr $bits, 49, 8),
       (ord pack 'B8', substr $bits, 57, 8),
    );
-   my ($width, $height, $offset)
-       = $sizecode == '000' ? ($d[0], $d[1], 16)
+   my ($width, $height, $offset) =
+         $sizecode == '000' ? ($d[0], $d[1], 16)
        : $sizecode == '001' ? ($d[0] * 256 + $d[1], $d[2] * 256 + $d[3], 32)
        : $sizecode == '010' ? (352, 288, 0)
        : $sizecode == '011' ? (176, 144, 0)
-       : $sizecode == '100' ? (128,  96, 0)
+       : $sizecode == '100' ? (128, 96,  0)
        : $sizecode == '101' ? (320, 240, 0)
        : $sizecode == '110' ? (160, 120, 0)
-       : die 'Illegal value for H.263 size code at byte ' . $pos;
+       :   die 'Illegal value for H.263 size code at byte ' . $pos;
 
    $self->{width}  = $width;
    $self->{height} = $height;
 
-   my $type = 1 + (substr $bits, 33+$offset, 1)*2 + substr $bits, 33+$offset+1, 1;
+   my $typebits = substr $bits, 33 + $offset, 2;
+   my @typebits = split m//xms, $typebits;
+   my $type = 1 + $typebits[0] * 2 + $typebits[1];
    if (!defined $self->{type})
    {
       $self->{type} = $type;
    }
    elsif ($type != $self->{type})
    {
-      warn "Type mismatch: header says $VIDEO_FRAME_TYPES{$self->{type}}, " .
-          "data says $VIDEO_FRAME_TYPES{$type}";
+      warn "Type mismatch: header says $VIDEO_FRAME_TYPES{$self->{type}}, "
+          . "data says $VIDEO_FRAME_TYPES{$type}";
    }
 
    return;
@@ -149,7 +151,10 @@ sub _parse_on2vp6
 
    if (!$self->{type})
    {
-      # Bit 7 of the header (after 8 bits of offset) distinguishes keyframe from interframe
+
+      # Bit 7 of the header (after 8 bits of offset) distinguishes
+      # keyframe from interframe
+      # See: http://use.perl.org/~ChrisDolan/journal/30427
       my @bytes = unpack 'CC', $self->{data};
       $self->{type} = ($bytes[1] & 0x80) == 0 ? 1 : 2;
    }
@@ -164,7 +169,9 @@ sub _parse_on2vp6_alpha
 
    if (!$self->{type})
    {
-      # Bit 7 of the header (after 32 bits of offset) distinguishes keyframe from interframe
+
+      # Bit 7 of the header (after 32 bits of offset) distinguishes
+      # keyframe from interframe
       my @bytes = unpack 'CCCCC', $self->{data};
       $self->{type} = ($bytes[4] & 0x80) == 0 ? 1 : 2;
    }
@@ -197,12 +204,28 @@ sub get_info
 {
    my $pkg = shift;
 
-   return $pkg->_get_info('video', {
-      type   => \%VIDEO_FRAME_TYPES,
-      codec  => \%VIDEO_CODEC_IDS,
-      width  => undef,
-      height => undef,
-   }, \@_);
+   return $pkg->_get_info(
+      'video',
+      {
+         type   => \%VIDEO_FRAME_TYPES,
+         codec  => \%VIDEO_CODEC_IDS,
+         width  => undef,
+         height => undef,
+      },
+      \@_
+   );
+}
+
+=item $self->is_keyframe()
+
+Returns a boolean.
+
+=cut
+
+sub is_keyframe
+{
+   my $self = shift;
+   return $self->{type} && $self->{type} == 1 ? 1 : undef;
 }
 
 1;
